#
# spec file for package re2
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global longver 2021-04-01
%global shortver %(echo %{longver}|sed 's|-||g')
%define libname libre2-9
Name:           re2
Version:        %{shortver}
Release:        bp153.4.1
Summary:        C++ fast alternative to backtracking RE engines
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
URL:            https://github.com/google/re2
Source0:        %{url}/archive/%{longver}/%{name}-%{longver}.tar.gz
Source99:       baselibs.conf
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig

%description
RE2 is a C++ library providing a fast, safe, thread-friendly alternative to
backtracking regular expression engines like those used in PCRE, Perl, and
Python.

Backtracking engines are typically full of features and convenient syntactic
sugar but can be forced into taking exponential amounts of time on even small
inputs.

In contrast, RE2 uses automata theory to guarantee that regular expression
searches run in time linear in the size of the input, at the expense of some
missing features (e.g. back references and generalized assertions).

%package -n %{libname}
Summary:        C++ fast alternative to backtracking RE engines
Group:          System/Libraries

%description -n %{libname}
RE2 is a C++ library providing a fast, safe, thread-friendly alternative to
backtracking regular expression engines like those used in PCRE, Perl, and
Python.

Backtracking engines are typically full of features and convenient syntactic
sugar but can be forced into taking exponential amounts of time on even small
inputs.

In contrast, RE2 uses automata theory to guarantee that regular expression
searches run in time linear in the size of the input, at the expense of some
missing features (e.g. back references and generalized assertions).

%package        devel
Summary:        C++ header files and library symbolic links for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description    devel
This package contains the C++ header files and symbolic links to the shared
libraries for %{name}. If you would like to develop programs using %{name},
you will need to install %{name}-devel.

%prep
%setup -q -n %{name}-%{longver}

%build
%if %{do_profiling}
  %make_build CXXFLAGS="%{optflags} %{cflags_profile_generate}"
  %make_build CXXFLAGS="%{optflags} %{cflags_profile_generate}" LDFLAGS="-lgcov" benchlog
  %make_build clean
  %make_build CXXFLAGS="%{optflags} %{cflags_profile_feedback}"
%else
  %make_build CXXFLAGS="%{optflags}"
%endif

%install
%make_install includedir=%{_includedir} libdir=%{_libdir}

# Suppress the static library
find %{buildroot} -name 'lib%{name}.a' -delete

%check
# Tests fail on all 32 bit architectures
%if %{__isa_bits} == 64
%make_build test CXXFLAGS="%{optflags}"
%endif

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%license LICENSE
%doc AUTHORS CONTRIBUTORS README
%{_libdir}/lib%{name}.so.*

%files devel
%license LICENSE
%{_includedir}/%{name}
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Thu Apr 15 2021 Andreas Stieger <andreas.stieger@gmx.de>
- Update to 2021-04-01:
  * Make cached benchmarks actually use cached objects
  * Address some -Wmissing-field-initializers warnings
  * Make it easier to swap in a scalable reaer-writer mutex
  * In the shared library, set compatibility version and
    current version
* Thu Feb  4 2021 Callum Farmer <gmbr3@opensuse.org>
- Update to version 2021-02-02:
  * Address `-Wnull-dereference' warnings from GCC 10.x.
* Thu Nov  5 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 2020-11-01:
  * Refactoring and fixes
* Sat Oct 10 2020 Andreas Stieger <andreas.stieger@gmx.de>
- update to 2020-10-01:
  * build system updates and compiler warnings fixes
* Tue Aug 11 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 2020-08-01:
  * Various internal changes
* Sun Jun  7 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 2020-06-01:
  * Various internal changes
* Fri May 29 2020 Martin Pluskal <mpluskal@suse.com>
- Enable PGO during build
* Wed May 20 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 2020-05-03:
  * Internal fixes and optimisations
  * Remove deprecated APIs, SONAME change
- Build tests with optflags
- Disable tests for 32 bit architectures
* Sun Apr  5 2020 Andreas Stieger <andreas.stieger@gmx.de>
- Updat to version 2020-04-01:
  * Update Unicode data to 13.0.0
  * Include the pattern length in "DFA out of memory" errorrs
* Fri Mar 20 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 2020-03-03:
  * various developer visible changes
* Thu Feb 13 2020 Martin Pluskal <mpluskal@suse.com>
- Small spec file update
* Wed Jan  8 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2020-01-01:
  * various developer visible changes
* Fri Dec  6 2019 Andreas Stieger <andreas.stieger@gmx.de>
- update to 2019-12-01:
  * fix latent bugs and undefined behavior
* Sat Nov 16 2019 Andreas Stieger <andreas.stieger@gmx.de>
- update to 2019-11-01:
  * new benchmark API
* Thu Sep 12 2019 Andreas Stieger <andreas.stieger@gmx.de>
- update to 2019-09-01:
  * build system fixes
* Fri Aug  2 2019 Andreas Stieger <andreas.stieger@gmx.de>
- Update to 2019-08-01:
  * Update Unicode data to 12.1.0
  * Various developer visible changes
* Mon Jul 22 2019 Martin Pluskal <mpluskal@suse.com>
- Fix download url
* Wed Jul 17 2019 Andreas Stieger <andreas.stieger@gmx.de>
- Update to 2019-07-01:
  * developer visible changes
* Wed Mar 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2019-03-01:
  * developer visible changes only
* Fri Jan  4 2019 astieger@suse.com
- update to 2019-01-01:
  * developer visible changes, performance tweaks and bug fixes
* Wed Oct 17 2018 Martin Pluskal <mpluskal@suse.com>
- update to 2018-10-01:
  * developer visible changes only
* Wed Sep  5 2018 astieger@suse.com
- update to 2018-09-01:
  * developer visible changes only
* Thu Aug 23 2018 astieger@suse.com
- update to 2018-08-01:
  * Fix the "DFA out of memory" error for the reverse Prog
* Fri Jul 20 2018 mpluskal@suse.com
- Simplify spec file a bit
* Fri Jul 20 2018 astieger@suse.com
- update to 2018-07-01:
  * Fix a "DFA out of memory" error
  * Update Unicode data to 11.0.0
  * Fix `-Wclass-memaccess' warnings and fallthrough macros
  * Use the standard first-byte analysis for the DFA too
* Fri Apr  6 2018 mpluskal@suse.com
- Update to version 2018-04-01
  * developer visible changes only
* Wed Mar 21 2018 astieger@suse.com
- update to 2018-03-01:
  * no longer linking against librd and libm
  * other developer visible changes
* Fri Feb  2 2018 astieger@suse.com
- update to 2018-02-01:
  * developer visible changes only
* Wed Jan  3 2018 mpluskal@suse.com
- Update to version 2018-01-01
  * No upstream changelog available
* Wed Jan  3 2018 dimstar@opensuse.org
- Add baselibs.conf: create libre2-0-32bit, dependency to
  libqt5-qtwebengine-32bit.
* Mon Dec 18 2017 mpluskal@suse.com
- Update to version 2017-12-01
  * No upstream changelog available
* Fri Nov  3 2017 mpluskal@suse.com
- Update to version 2017-11-01
  * No upstream changelog available
* Mon Sep  4 2017 mpluskal@suse.com
- Update to version 2017-07-01
  * No upstream changelog available
* Sat Jul 29 2017 mpluskal@suse.com
- Update to version 2017-07-01
  * No upstream changelog available
* Sun Jun 11 2017 mpluskal@suse.com
- Update to version 2017-06-01
  * No upstream changelog available
* Fri May 19 2017 vsistek@suse.com
- Update to version 2017-05-01
  * No upstream changelog available
* Thu Apr 13 2017 mpluskal@suse.com
- Update to version 2017-04-01
  * No upstream changelog available
* Thu Mar 16 2017 mpluskal@suse.com
- Update to version 2017-03-01
  * No upstream changelog available
* Sat Jan 14 2017 mpluskal@suse.com
- Update to version 2017-01-01
  * No upstream changelog available
* Sat Dec  3 2016 mpluskal@suse.com
- Update to version 2016-11-01:
  * No upstream changelog available
- Drop no longer needed re2-gcc61.patch
* Sat Oct 22 2016 jengelh@inai.de
- Fixup group and avoid rm indirection
* Thu Sep  8 2016 mpluskal@suse.com
- Drop releasenumber
* Wed Sep  7 2016 tchvatal@suse.com
- Version update to 2016-09-01 version
  * Various changes based on google needs, long changelog in upstream
    github repo
- Rebase spec on Fedora package
- Add patch to build with gcc 6.1:
  * re2-gcc61.patch
* Fri Dec 21 2012 aplanas@novell.com
- Initial package version.
